@@ -1,6 +1,7 @@
-from typing import Any, List, Type
+from typing import Any, List, Type, Union
 
-from antlr4.tree.Tree import ParseTree
+from antlr4 import Token
+from antlr4.tree.Tree import ParseTree, Tree
 
 from fugue_sql_antlr._parser.fugue_sqlVisitor import fugue_sqlVisitor
 from fugue_sql_antlr.parser import FugueSQLParser
@@ -23,3 +24,16 @@ class FugueSQLVisitor(fugue_sqlVisitor):
             if isinstance(c, tp):
                 result.append(c.accept(self))
         return result
+
+    def _str(
+        self,
+        node: Union[Tree, Token, None],
+        delimit: str = " ",
+        upper_keyword: bool = False,
+    ) -> str:
+        return self.sql.get_norm_text(
+            node, delimiter=delimit, upper_keyword=upper_keyword
+        )
+
+    def _orig_str(self, node: Union[Tree, Token, None]) -> str:
+        return self.sql.get_raw_text(node)
